# Table of Contents

- [managing-surveys-and-viewing-results](<./managing-surveys-and-viewing-results.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Managing Surveys and Viewing Results](<./Managing-Surveys-and-Viewing-Results.md>)
  - [Filter, Sort, and Search Surveys](<./Managing-Surveys-and-Viewing-Results/Filter-Sort-and-Search-Surveys.md>)
  - [Viewing Survey Results](<./Managing-Surveys-and-Viewing-Results/Viewing-Survey-Results.md>)
  - [Finishing a Survey](<./Managing-Surveys-and-Viewing-Results/Finishing-a-Survey.md>)
  - [Survey History](<./Managing-Surveys-and-Viewing-Results/Survey-History.md>)
  - [Restarting a Survey](<./Managing-Surveys-and-Viewing-Results/Restarting-a-Survey.md>)
  - [Deleting a Survey](<./Managing-Surveys-and-Viewing-Results/Deleting-a-Survey.md>)
  - [Deleting a Survey Run](<./Managing-Surveys-and-Viewing-Results/Deleting-a-Survey-Run.md>)
